@@ -347,7 +347,7 @@ class BamBaseCaller(object):
                     self.buffer[buf_idx].records.append(mr)
                     buf_idx += 1
             elif op == 4:  # S - soft clipping
-                read_idx += 1
+                read_idx += length
                 pass
             elif op == 5:  # H - hard clipping
                 pass
